[![Build Status](https://travis-ci.org/Python-Logging-For-Human/ezlogging.svg?branch=master)](https://travis-ci.org/Python-Logging-For-Human/ezlogging)

# ezlogging

ezlogging

https://paper.dropbox.com/doc/Logging-For-Human-0hgb3uUWhAgi4kJcU3r5X



# test
py.test --capture=sys
